@@ -491,6 +491,8 @@ class Model:
 
             # Try to get the item in DB
             name_count = missing_names = 0
+            # Always use dir() (instead of vars()) to get the variables from
+            # parent classes.
             for name in dir(self.__class__):
                 if name.startswith('_'): continue
 
@@ -619,7 +621,9 @@ class Model:
         if self.__class__._AUTO_ID and self._id >= 0 and self.__class__._INDEXES:
             keys_indexes = []
 
-        for name in vars(self.__class__):
+        # Always use dir() (instead of vars()) to get the variables from parent
+        # classes.
+        for name in dir(self.__class__):
             if name.startswith('_'): continue
 
             attr = getattr(self.__class__, name)
